@@ -1,7 +1,6 @@
 #ifndef FM_H
 #define FM_H
 
-#include <QHash>
 #include <QObject>
 
 #include <QStringList>
@@ -31,6 +30,8 @@ class FileLoader;
 class QDirLister : public QObject
 {
     Q_OBJECT
+    Q_DISABLE_COPY(QDirLister)
+    
 public:
     explicit QDirLister(QObject *parent = nullptr);
 
@@ -95,7 +96,8 @@ class Syncing;
 class FILEBROWSING_EXPORT FM : public QObject
 {
     Q_OBJECT
-
+    Q_DISABLE_COPY(FM)
+    
 public:
     FM(QObject *parent = nullptr);
 
@@ -168,7 +170,7 @@ private:
     QDirLister *dirLister;
 #endif
 
-signals:
+Q_SIGNALS:
     void cloudServerContentReady(FMH::MODEL_LIST list, const QUrl &url);
     void cloudItemReady(FMH::MODEL item, QUrl path); // when a item is downloaded and ready
 
